Package 'Tverse'

Title: Meta package that installs my most commonly used packages
Description: Meta package that installs my most commonly used packages.
Authors: Stephen Turner [aut, cre] (ORCID: <https://orcid.org/0000-0001-9140-9028>)
Maintainer: Stephen Turner <[email protected]>
License: MIT + file LICENSE
Version: 0.2.0
Built: 2026-05-28 06:55:39 UTC
Source: https://github.com/stephenturner/Tverse

Help Index